@@ -17,5 +17,9 @@ __all__ = [
     "operators",
     "newline_at_end_of_file",
     "subscriptor",
-    "header"
+    "header",
+]
+
+PREVIEW = [
+   "nb_params"
 ]
