@@ -5,8 +5,9 @@ except ModuleNotFoundError:
     from normatrix.normatrix.source.file_parser import CFileParse
     from normatrix.normatrix.source.config import TypeLine
 
-def check(context, file: CFileParse) -> (int, int):
+def check(context, file: CFileParse) -> (int, int, list):
     nb_error = 0
+    list_error = []
     for i in range(len(file.real_parsedline)):
         line = file.real_parsedline[i]
         if line[0] == TypeLine.COMMENT:
@@ -16,6 +17,12 @@ def check(context, file: CFileParse) -> (int, int):
         while len_l > 0 and nb_space < len_l and line[1][nb_space] == ' ':
             nb_space += 1
         if nb_space % 4 != 0:
-            print(f"{file.basename}:{i + 1}: always four indent in source code")
+            list_error.append((i + 1, "always four indent in source code"))
             nb_error += 1
-    return (nb_error, 1)
+        if not (file.basename.endswith(".c") or file.basename.endswith(".h")):
+            continue
+        ll: str = line[1]
+        if ll.strip().startswith("\t") or ll.strip().endswith("\t"):
+            list_error.append((i + 1, "no \\t for indentation"))
+            nb_error += 1
+    return (nb_error, 1, list_error)
