@@ -12,13 +12,18 @@ reg = re.compile('^(?!.*=)(\w{1,} {0,1}){2,}\((.*?\n{0,1}){0,}?\) {0,1}\n{0,1}\{
 def get_only_func_decl(rest: str):
     res = reg.match(rest)
     if res != None:
-        return rest[res.start():res.end()]
+        only_decl = rest[res.start():res.end()]
+        if "=" in only_decl:
+            return ''
+        return only_decl
     return ''
 
-def check(context, file: CFileParse) -> (int, int):
+def check(context, file: CFileParse) -> (int, int, list):
     nb_error = 0
+    list_error = []
+
     if file.basename.endswith('.h'):
-        return (0, 0)
+        return (0, 0, [])
     for i, line in enumerate(file.sub_parsedline):
         if line[0] == TypeLine.COMMENT:
             continue
@@ -28,6 +33,6 @@ def check(context, file: CFileParse) -> (int, int):
         only_decl = re.sub("\(\*\w*?\)\((.|\n)*?\)", "", only_decl)
         n = only_decl.count(',') + 1
         if n > 4:
-            print(f"{file.basename}:{i + 1}: too many arguments ({n} > 4)")
+            list_error.append((i + 1, f"too many arguments ({n} > 4)"))
             nb_error += 1
-    return (nb_error, 0)
+    return (nb_error, 0, list_error)
