@@ -5,9 +5,8 @@ except ModuleNotFoundError:
 
 import os
 
-def check(context, file: CFileParse) -> (int, int):
+def check(context, file: CFileParse) -> (int, int, list):
     for char in os.path.basename(file.basename):
         if char in [chr(i) for i in range(ord('A'), ord('Z') + 1)]:
-            print(f"{file.basename}: only lower case in file name")
-            return (1, 0)
-    return (0, 0)
+            return (1, 0, [(0, "only lower case in file name")])
+    return (0, 0, [])
