@@ -9,6 +9,8 @@ import re
 
 def check(context, file: CFileParse) -> (int, int):
     nb_error = 0
+    list_error = []
+
     for i in range(len(file.sub_parsedline)):
         line = file.sub_parsedline[i]
         if line[0] != TypeLine.COMMENT:
@@ -17,6 +19,6 @@ def check(context, file: CFileParse) -> (int, int):
             ll = re.sub("//.*", '', ll)
             nb = ll.count(';')
             if nb > 1 and 'for' not in ll:
-                print(f"{file.basename}:{i + 1}: only one statement per line")
+                list_error.append((i + 1, f"only one statement per line ({ll})"))
                 nb_error += 1
-    return (nb_error, 0)
+    return (nb_error, 0, list_error)
