@@ -7,8 +7,10 @@ except ModuleNotFoundError:
 
 import re
 
-def check(context, file: CFileParse) -> (int, int):
+def check(context, file: CFileParse) -> (int, int, list):
     nb_error = 0
+    list_error = []
+
     for i, line in enumerate(file.sub_parsedline):
         if line[0] != TypeLine.COMMENT:
             ll = re.sub(".*?\*\/", '', line[1])
@@ -16,6 +18,8 @@ def check(context, file: CFileParse) -> (int, int):
             ll = re.sub("//.*", '', ll)
             m = re.search('(\[ )|( \])', ll)
             if m != None:
-                print(f"{file.basename}:{i + 1}: no space after [ or before ]")
+                list_error.append(
+                        (i + 1, f"no space after [ or before ] ({line[1]})")
+                )
                 nb_error += 1
-    return (nb_error, 0)
+    return (nb_error, 0, list_error)
