@@ -39,7 +39,7 @@ OPERATOR_LIST = [
         ('([ ',     '!',    ':ALL:'),
         ('/+*-=! ', '=',    '= '),
         (':ALL:',   '(',    ':ALL:'),
-        (':ALL:',   ')',    '}]) ;')
+        (':ALL:',   ')',    '}]) ;',        '\)\)')
 ]
 
 class TypeLine(Enum):
