@@ -69,6 +69,10 @@ def call_argparse():
     parser.add_argument('--only-error', action='store_const',
             dest='only_error', const='yes', default='no',
             help='print only bad files with errors')
+    parser.add_argument('--output', metavar="format",
+            choices=["html", "md", "term_color"], dest='output_format',
+            default="term_color",
+            help='tell which output format to use [html, md, term_color]; for html the file is normatrix-result.htmk; for md the file is normatrix-result.md')
     result = parser.parse_args()
     if result.paths == []:
         result.paths.append(os.getcwd())
@@ -81,8 +85,14 @@ def check_norm_path(pwd: str, context: Context, plug_operator_activ: bool, previ
     if preview or context.ENABLE_PREVIEW == True:
         list_checkers.extend(plugged.PREVIEW)
 
-    color.print_color("green", "\nNorMatrix!")
-    color.print_color("cyan", f"directory to check: {pwd}\n")
+    if context.output_format in ["html", "md"]:
+        with open(context.output_file, "a") as file:
+            print("\n\n# NorMatrix!", file=file)
+            print(f"## Directory: {pwd}", file=file)
+            print("", file=file)
+    elif context.output_format == "term_color":
+        color.print_color("green", "\nNorMatrix!")
+        color.print_color("cyan", f"directory to check: {pwd}\n")
 
     stats, files_to_check = get_file_to_check.get_file_to_check(pwd)
 
@@ -91,13 +101,21 @@ def check_norm_path(pwd: str, context: Context, plug_operator_activ: bool, previ
     STATS.extend(stats)
     NB_ERROR += len(stats)
 
-    print_stats.print_stats(STATS, files_to_check)
+    print_stats.print_stats(context, STATS, files_to_check)
 
     if NB_ERROR == 0:
-        color.print_color("green", "OK BRO")
+        if context.output_format in ["html", "md"]:
+            with open(context.output_file, "a") as file:
+                print(f"## Directory: {pwd} is **OK**", file=file)
+        elif context.output_format == "term_color":
+            color.print_color("green", "OK BRO")
         return 0
     else:
-        color.print_color("red", f"DUMB BRO ({NB_ERROR} error{'' if NB_ERROR == 0 else 's'})")
+        if context.output_format in ["html", "md"]:
+            with open(context.output_file, "a") as file:
+                print(f"## Directory: {pwd} is **BAD** with **{NB_ERROR}** error.s", file=file)
+        elif context.output_format == "term_color":
+            color.print_color("red", f"DUMB BRO ({NB_ERROR} error.s)")
         return NB_ERROR
 
 def main():
@@ -108,9 +126,9 @@ def main():
     for path in result.paths:
         curr_ret_code = 0
         if result.configs == "yes":
-            context = Context(os.path.join(path, ".normatrix.json"), result.only_error)
+            context = Context(os.path.join(path, ".normatrix.json"), result.only_error, result.output_format)
         else:
-            context = Context(None, result.only_error)
+            context = Context(None, result.only_error, result.output_format)
         if check_norm_path(path, context, is_plugin_operator, is_preview) != 0:
             curr_ret_code += 1
         if makefile.check(context, path)[0] != 0:
@@ -118,8 +136,18 @@ def main():
         if curr_ret_code != 0:
             ret_code += 1
     if ret_code != 0:
-        if len(result.paths) == 1:
+        if context.output_format in ["html", "md"]:
+            with open(context.output_file, "a") as file:
+                print(f"\n# You Have {ret_code} folder.s that dont respect the norm", file=file)
+        elif context.output_format == "term_color":
+            print(f'\nYou Have {ret_code} folder.s that dont respect the norm')
+    if result.output_format == "html":
+        try:
+            from markdown import Markdown
+        except ModuleNotFoundError:
+            print("you should install the markdown package first (pip install markdown)")
             exit(1)
-        print(f'\nYou Have {ret_code} folder that dont respect the norm')
-        exit(1)
-    exit(0)
+        mark = Markdown()
+        mark.convertFile(input=context.output_file, output=context.output_file.replace(".md", ".html"))
+        os.remove(context.output_file)
+    exit(0 if ret_code == 0 else 1)
